==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Stretch/ts/Stretch_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Stretch</name>
    <message>
        <location filename="../Stretch.js" line="+59"/>
        <source>First corner</source>
        <translatorcomment>--google--
Wskaż pierwszy wierzchołek</translatorcomment>
        <translation type="unfinished">Pierwszy zakręt</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second corner</source>
        <translatorcomment>--google--
Wskaż drugi wierzchołek</translatorcomment>
        <translation type="unfinished">Drugi narożnik</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation type="unfinished">Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation type="unfinished">Punkt docelowy</translation>
    </message>
    <message>
        <location filename="../StretchInit.js" line="+2"/>
        <source>&amp;Stretch</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Rozciągnij</translatorcomment>
        <translation type="unfinished">&amp;Rozciągnij</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Stretch/ts/Stretch_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Stretch</name>
    <message>
        <location filename="../Stretch.js" line="+59"/>
        <source>First corner</source>
        <translatorcomment>--google--
Wskaż pierwszy wierzchołek</translatorcomment>
        <translation>Pierwszy narożnik</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second corner</source>
        <translatorcomment>--google--
Wskaż drugi wierzchołek</translatorcomment>
        <translation>Drugi narożnik</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation>Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation>Punkt docelowy</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>No selected entities in given range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No entities in given range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../StretchInit.js" line="+2"/>
        <source>&amp;Stretch</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Rozciągnij</translatorcomment>
        <translation>&amp;Rozciągnij</translation>
    </message>
</context>
</TS>
